function love.load()
love.graphics.setColor(255,255,255)

	font = {}
	font.default = love.graphics.newFont(12)
	font.huuuge  = love.graphics.newFont(96)

	point = {}

	world = {}
	world.meter   = 64
	world.gravity = world.meter * 9.81
	world.width   = love.graphics.getWidth()
	world.height  = love.graphics.getHeight()-world.meter+2

	
	ground = {}
	ground.draw = function (x,y)
		love.graphics.setLine(8, 'rough')
		love.graphics.line(-8,world.height+y,world.width+8,world.height+y)
		love.graphics.setColor(0,0,0)
			love.graphics.point(point.x, world.height)
			love.graphics.point(point.x+world.width/2, world.height)
			love.graphics.point(point.x-world.width/2, world.height)
		love.graphics.setColor(255,255,255)
	end

	camera = {}
	camera.x = 0
	camera.y = 0
	camera.update = function(dt)
		if ball.x - camera.x > 768 then
			camera.x = ball.x - 768
		end
		if ball.y < camera.y then
			camera.y = -ball.y
		end
	end
	
	ball = {}
	ball.launched = false
	ball.x      = 0
	ball.y      = world.height
	ball.maxHeight = world.height - ball.y
	ball.radius = world.meter/2
	ball.bounce = 50
	ball.vel = {}
	ball.vel.x = 0
	ball.vel.y = 0
	ball.acc = {}
	ball.acc.x = 0
	ball.acc.y = 0
	ball.move = function(dt, dir)
		ball[dir] = ball[dir] + ball.vel[dir]*dt
	end
	ball.draw = function(x,y)
		love.graphics.setLine(4, 'rough')
		love.graphics.circle('line',ball.x-x+ball.radius, ball.y+y+ball.radius, ball.radius)
		if camera.y > world.meter then
			love.graphics.printf(math.floor((world.height-ball.y)/world.meter*10)/10-1 .. 'm', ball.x-x, ball.y+y+ball.radius*2, ball.radius*2, 'center')
		end
	end
	ball.collide = {}
	ball.collide.x = function() --[[function]] end
	ball.collide.y = function()
		if ball.y+ball.radius*2 > world.height and ball.vel.y > 0 then
			ball.y = world.height - ball.radius*2
			ball.vel.y = math.sqrt(math.abs(world.gravity*6/4*ball.maxHeight))*-1
			ball.maxHeight = ball.maxHeight * 3 / 4
			ball.vel.x = ball.vel.x *31/32
			if ball.launched then ball.bounced = true end
		end
	end
	ball.old = {}
		ball.old.vel = {x = ball.vel.x, y = ball.vel.y}
end


function love.update(dt)
	if not ball.bounced and ball.launched then
		ball.maxHeight = math.max(world.height-ball.y, ball.maxHeight)
	end
	ball.old.vel.y = ball.vel.y
	ball.vel.y = ball.vel.y + world.gravity*dt
	ball.move(dt,'y')
	ball.move(dt,'x')
	ball.collide.y()
	ball.old.vel = {x = ball.vel.x, y = ball.vel.y}
	camera.update(dt)
	point.x = math.ceil(camera.x / world.width)*world.width - camera.x
end

function love.mousepressed(x,y,b)
	if not ball.launched and b == 'l' then
		local angle = math.atan2(0+ball.radius-x, world.height-ball.radius-y)
		if angle >= 0 then
			return
		end
		ball.vel.x = (world.gravity*2)*math.sin(angle)*-1
		ball.vel.y = (world.gravity*2)*math.cos(angle)*-1
		ball.launched = true
	end
end

love.graphics.setPoint(6, 'smooth')

function love.draw()
	if ball.vel.x <= .005 and ball.launched then
		love.graphics.setFont(font.huuuge)
		love.graphics.printf('Game Over',0,256,1024,'center')
		love.graphics.setFont(font.default)
		love.graphics.printf('You bounced for ' .. math.floor(ball.x/world.meter*10)/10 .. ' meters',0,384,1024,'center')
		love.graphics.setColor(128,128,128)
	end
	love.graphics.print(math.floor(ball.x/world.meter*10)/10 .. 'm',0,0) --prints meters
	ball.draw(camera.x,camera.y)
	ground.draw(camera.x,camera.y)
end